==> packed_packs-fabric-2.0.2%2B1.21.9-sources.jar: io/github/fishstiz/packed_packs/compat/ModContext.java <==
package io.github.fishstiz.packed_packs.compat;

import io.github.fishstiz.packed_packs.PackedPacks;
import io.github.fishstiz.packed_packs.util.ResourceUtil;
import org.apache.commons.lang3.function.TriConsumer;

import java.util.function.BiConsumer;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.function.Supplier;
import net.minecraft.class_2960;

public interface ModContext {
    String getId();

    boolean isLoaded();

    default class_2960 getInternalId() {
        return ResourceUtil.getResource(this.getId());
    }

    private void logError(Throwable e) {
        PackedPacks.LOGGER.warn("[packed_packs] Error occurred while applying compatibility for mod '{}'", this.getId(), e);
    }

    default <T> T wrapError(Supplier<T> supplier, T defaultValue) {
        if (this.isLoaded()) {
            try {
                return supplier.get();
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
        return defaultValue;
    }

    default <T, R> R wrapError(Function<T, R> mapper, R defaultValue, T value) {
        if (this.isLoaded()) {
            try {
                return mapper.apply(value);
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
        return defaultValue;
    }

    default <T> void wrapError(T arg, Consumer<T> consumer) {
        if (this.isLoaded()) {
            try {
                consumer.accept(arg);
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
    }

    default <T1, T2> void wrapError(T1 arg1, T2 arg2, BiConsumer<T1, T2> consumer) {
        if (this.isLoaded()) {
            try {
                consumer.accept(arg1, arg2);
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
    }

    default <T1, T2, T3> void wrapError(T1 arg1, T2 arg2, T3 arg3, TriConsumer<T1, T2, T3> consumer) {
        if (this.isLoaded()) {
            try {
                consumer.accept(arg1, arg2, arg3);
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
    }
}

==> packed_packs-fabric-2.0.3%2B1.21.11-sources.jar: io/github/fishstiz/packed_packs/compat/ModContext.java <==
package io.github.fishstiz.packed_packs.compat;

import io.github.fishstiz.packed_packs.PackedPacks;
import io.github.fishstiz.packed_packs.util.ResourceUtil;
import java.util.function.BiConsumer;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.function.Supplier;
import net.minecraft.class_2960;

public interface ModContext {
    String getId();

    boolean isLoaded();

    default class_2960 getInternalId() {
        return ResourceUtil.id(this.getId());
    }

    private void logError(Throwable e) {
        PackedPacks.LOGGER.warn("[packed_packs] Error occurred while applying compatibility for mod '{}'", this.getId(), e);
    }

    default <T> T wrapError(Supplier<T> supplier, T defaultValue) {
        if (this.isLoaded()) {
            try {
                return supplier.get();
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
        return defaultValue;
    }

    default <T, R> R wrapError(Function<T, R> mapper, R defaultValue, T value) {
        if (this.isLoaded()) {
            try {
                return mapper.apply(value);
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
        return defaultValue;
    }

    default <T> void wrapError(T arg, Consumer<T> consumer) {
        if (this.isLoaded()) {
            try {
                consumer.accept(arg);
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
    }

    default <T1, T2> void wrapError(T1 arg1, T2 arg2, BiConsumer<T1, T2> consumer) {
        if (this.isLoaded()) {
            try {
                consumer.accept(arg1, arg2);
            } catch (LinkageError | Exception e) {
                this.logError(e);
            }
        }
    }
}
